==> haskell-kan-extensions-5.2.7-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kan-extensions
version:              5.2.7
visibility:           public
id:                   kan-extensions-5.2.7-HreC945BxPREYCYidFsDyq
key:                  kan-extensions-5.2.7-HreC945BxPREYCYidFsDyq
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/kan-extensions/
synopsis:
    Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads

description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.

category:             Data Structures, Monads, Comonads, Functors
abi:                  c40b8955e6caf63aa50842f49bab93b9
exposed:              True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kan-extensions
hs-libraries:         HSkan-extensions-5.2.7-HreC945BxPREYCYidFsDyq
depends:
    adjunctions-4.4.3-IaMXvCj95cEKXB0CRhlM5n array-0.5.4.0
    base-4.17.2.1 comonad-5.0.9-Ar7cnVEb1Pi60zh00XTpgG containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-3pp9fAdpywz61tusPhXfY2
    free-5.2-DQKJhVM9aV54TCIirnEDnt
    invariant-0.6.4-LSwPviTKjBYBj0GvyYmei8 mtl-2.2.2
    profunctors-5.6.3-H3aGaptwIhVL5gQLua9Hf2
    semigroupoids-6.0.1-4CnZvgWKSH6LO3xaxoiG8y
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock

haddock-html:         /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kan-extensions-5.2.7-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kan-extensions
version:              5.2.7
visibility:           public
id:                   kan-extensions-5.2.7-B7sMNvxhXLRF4WiW38pwEY
key:                  kan-extensions-5.2.7-B7sMNvxhXLRF4WiW38pwEY
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/kan-extensions/
synopsis:
    Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads

description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.

category:             Data Structures, Monads, Comonads, Functors
abi:                  fcee32aae1219d6392c00e6a2475d1cf
exposed:              True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kan-extensions
hs-libraries:         HSkan-extensions-5.2.7-B7sMNvxhXLRF4WiW38pwEY
depends:
    adjunctions-4.4.3-DmziOjHQ3x64HXdgT4ujN4 array-0.5.4.0
    base-4.17.2.1 comonad-5.0.9-F3uF2UZEfOQ4mXlrEuQWeg containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-WfwBxAWOiHFEceCi06Yyf
    free-5.2-L6IFLTK1Mi66tRzvv6UvnV
    invariant-0.6.4-4rxCqe9S0q5DRxj7mffGe2 mtl-2.2.2
    profunctors-5.6.3-FiHazNoTbSuEkaVv0xHC9t
    semigroupoids-6.0.1-77kKp314gaoHAvgGjZ9Eia
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock

haddock-html:         /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
